import { A } from "@solidjs/router";
import { defaultTo, isNil, pick, pipe, prop } from "ramda";
import { Show } from "solid-js";
import classes from "./ActivatableLink.module.css";

/**
 * @typedef {import("@solidjs/router").AnchorProps} AnchorProps
 * @typedef {import("solid-js").ParentProps} ParentProps
 * @typedef {Partial<AnchorProps> & ParentProps} ActivatableLinkBase
 *
 * @typedef {Object} ActivatableLinkExtends
 * @property {string} href
 * @property {boolean} [activatable]
 * @property {JSX.Element} [leftIcon]
 * @property {JSX.Element} [rightIcon]
 *
 * @typedef {ActivatableLinkBase & ActivatableLinkExtends} ActivatableLinkProps
 */

const defaultActivatable = pipe(defaultTo(true), prop("activatable"));

/**
 * @param {ActivatableLinkProps} props
 * @returns {import("solid-js").Component<ActivatableLinkProps>}
 */
export default function ActivatableLink(props) {
  return (
    <A
      class={prop("activatable-link", classes)}
      {...(defaultActivatable(props) && {
        activeClass: "activated",
      })}
      {...pick(["replace", "end", "href"], props)}
    >
      <Show when={!isNil(props.leftIcon)}>{props.leftIcon}</Show>
      <Show when={!isNil(props.children)}>{props.children}</Show>
      <Show when={!isNil(props.rightIcon)}>{props.rightIcon}</Show>
    </A>
  );
}
